list_workspace_registry

Function list_workspace_registry 

pub fn list_workspace_registry(
    database_path: &Path,
) -> Result<Vec<WorkspaceRegistryItem>, ApplicationError>
Lists persisted workspaces without mutating or migrating the database.

Errors

Returns ApplicationError when the database or registry cannot be read.