restore_database

Function restore_database 

pub fn restore_database(
    database_path: &Path,
    backup_path: &Path,
) -> Result<RestoreSummary, ApplicationError>
Restores a validated backup while preserving the replaced database.

Errors

Returns ApplicationError when locking, validation, safety backup, or restore fails.