sync_workspace_with_worker_executable

Function sync_workspace_with_worker_executable 

pub fn sync_workspace_with_worker_executable(
    config_path: &Path,
    database_path: &Path,
    overrides: &ScanOverrides,
    synchronize_codegraph: bool,
    worker_executable: &Path,
) -> Result<SyncSummary, ApplicationError>
Synchronizes through an explicitly selected compatible worker executable.

Embedding applications can pass their own executable after dispatching __worker-v1 to [crate::run_worker_from_stdio].

Errors

Returns ApplicationError when the worker cannot start or synchronization fails.