pub struct WorkspaceMutationSummary {
pub workspace: String,
pub config_path: Option<String>,
pub repository_count: usize,
pub operation: String,
}Expand description
Result of adding or removing a persisted workspace registration.
Fields
workspace: StringWorkspace name.
config_path: Option<String>Canonical manifest display path when adding.
repository_count: usizeNumber of registered repository aliases before removal or after addition.
operation: StringMutation kind.