list_pull_requests

Function list_pull_requests 

pub async fn list_pull_requests(
    input: &PullRequestListInput,
    enabled: bool,
    token: Option<String>,
    basic_auth_username: Option<String>,
    cancellation: CancellationToken,
) -> Result<ToolEnvelope<PullRequestListPage>, ApplicationError>
Lists one bounded page of source-free hosted pull-request summaries.

Errors

Returns ApplicationError for disabled providers, missing consent, invalid bounds or cursors, cancellation, timeouts, rate limits, malformed responses, or unsupported providers.